==> apache-airflow-2.2.2-source.tar.gz: apache-airflow-2.2.2/docs/exts/docs_build/third_party_inventories.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

THIRD_PARTY_INDEXES = {
    'boto3': 'https://boto3.amazonaws.com/v1/documentation/api/latest',
    'celery': 'https://docs.celeryproject.org/en/stable',
    'docker': 'https://docker-py.readthedocs.io/en/stable',
    'hdfs': 'https://hdfscli.readthedocs.io/en/latest',
    'jinja2': 'https://jinja.palletsprojects.com/en/2.11.x',
    'mongodb': 'https://pymongo.readthedocs.io/en/3.11.3',
    'pandas': 'https://pandas.pydata.org/pandas-docs/stable',
    'python': 'https://docs.python.org/3',
    'requests': 'https://requests.readthedocs.io/en/master',
    'sqlalchemy': 'https://docs.sqlalchemy.org/en/latest',
    'google-api-core': 'https://googleapis.dev/python/google-api-core/latest',
    'google-cloud-automl': 'https://googleapis.dev/python/automl/latest',
    'google-cloud-bigquery': 'https://googleapis.dev/python/bigquery/latest',
    'google-cloud-bigquery-datatransfer': 'https://googleapis.dev/python/bigquerydatatransfer/latest',
    'google-cloud-bigquery-storage': 'https://googleapis.dev/python/bigquerystorage/latest',
    'google-cloud-bigtable': 'https://googleapis.dev/python/bigtable/latest',
    'google-cloud-container': 'https://googleapis.dev/python/container/latest',
    'google-cloud-core': 'https://googleapis.dev/python/google-cloud-core/latest',
    'google-cloud-datacatalog': 'https://googleapis.dev/python/datacatalog/latest',
    'google-cloud-datastore': 'https://googleapis.dev/python/datastore/latest',
    'google-cloud-dlp': 'https://googleapis.dev/python/dlp/latest',
    'google-cloud-kms': 'https://googleapis.dev/python/cloudkms/latest',
    'google-cloud-language': 'https://googleapis.dev/python/language/latest',
    'google-cloud-monitoring': 'https://googleapis.dev/python/monitoring/latest',
    'google-cloud-pubsub': 'https://googleapis.dev/python/pubsub/latest',
    'google-cloud-redis': 'https://googleapis.dev/python/redis/latest',
    'google-cloud-spanner': 'https://googleapis.dev/python/spanner/latest',
    'google-cloud-speech': 'https://googleapis.dev/python/speech/latest',
    'google-cloud-storage': 'https://googleapis.dev/python/storage/latest',
    'google-cloud-tasks': 'https://googleapis.dev/python/cloudtasks/latest',
    'google-cloud-texttospeech': 'https://googleapis.dev/python/texttospeech/latest',
    'google-cloud-translate': 'https://googleapis.dev/python/translation/latest',
    'google-cloud-videointelligence': 'https://googleapis.dev/python/videointelligence/latest',
    'google-cloud-vision': 'https://googleapis.dev/python/vision/latest',
}

==> apache-airflow-2.3.1-source.tar.gz: apache-airflow-2.3.1/docs/exts/docs_build/third_party_inventories.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

THIRD_PARTY_INDEXES = {
    'boto3': 'https://boto3.amazonaws.com/v1/documentation/api/latest',
    'celery': 'https://docs.celeryq.dev/en/stable/',
    'docker': 'https://docker-py.readthedocs.io/en/stable',
    'hdfs': 'https://hdfscli.readthedocs.io/en/latest',
    'jinja2': 'https://jinja.palletsprojects.com/en/2.11.x',
    'mongodb': 'https://pymongo.readthedocs.io/en/3.11.3',
    'pandas': 'https://pandas.pydata.org/pandas-docs/stable',
    'python': 'https://docs.python.org/3',
    'requests': 'https://requests.readthedocs.io/en/master',
    'sqlalchemy': 'https://docs.sqlalchemy.org/en/latest',
    'google-api-core': 'https://googleapis.dev/python/google-api-core/latest',
    'google-cloud-automl': 'https://googleapis.dev/python/automl/latest',
    'google-cloud-bigquery': 'https://googleapis.dev/python/bigquery/latest',
    'google-cloud-bigquery-datatransfer': 'https://googleapis.dev/python/bigquerydatatransfer/latest',
    'google-cloud-bigquery-storage': 'https://googleapis.dev/python/bigquerystorage/latest',
    'google-cloud-bigtable': 'https://googleapis.dev/python/bigtable/latest',
    'google-cloud-container': 'https://googleapis.dev/python/container/latest',
    'google-cloud-core': 'https://googleapis.dev/python/google-cloud-core/latest',
    'google-cloud-datacatalog': 'https://googleapis.dev/python/datacatalog/latest',
    'google-cloud-datastore': 'https://googleapis.dev/python/datastore/latest',
    'google-cloud-dlp': 'https://googleapis.dev/python/dlp/latest',
    'google-cloud-kms': 'https://googleapis.dev/python/cloudkms/latest',
    'google-cloud-language': 'https://googleapis.dev/python/language/latest',
    'google-cloud-monitoring': 'https://googleapis.dev/python/monitoring/latest',
    'google-cloud-pubsub': 'https://googleapis.dev/python/pubsub/latest',
    'google-cloud-redis': 'https://googleapis.dev/python/redis/latest',
    'google-cloud-spanner': 'https://googleapis.dev/python/spanner/latest',
    'google-cloud-speech': 'https://googleapis.dev/python/speech/latest',
    'google-cloud-storage': 'https://googleapis.dev/python/storage/latest',
    'google-cloud-tasks': 'https://googleapis.dev/python/cloudtasks/latest',
    'google-cloud-texttospeech': 'https://googleapis.dev/python/texttospeech/latest',
    'google-cloud-translate': 'https://googleapis.dev/python/translation/latest',
    'google-cloud-videointelligence': 'https://googleapis.dev/python/videointelligence/latest',
    'google-cloud-vision': 'https://googleapis.dev/python/vision/latest',
}
